@@ -50,7 +50,7 @@ sub create_field
 
         # Create the declaration
         my @errs;
-        local $SIG{__WARN__} = sub { push(@errs, @_); };
+        local $SIG{'__WARN__'} = sub { push(@errs, @_); };
 
         my $code = "package $class; my $field :Field$attr;";
         eval $code;
@@ -79,5 +79,5 @@ sub create_field
 
 
 # Ensure correct versioning
-my $VERSION = 1.49;
-($Object::InsideOut::VERSION == 1.49) or die("Version mismatch\n");
+my $VERSION = 1.51;
+($Object::InsideOut::VERSION == 1.51) or die("Version mismatch\n");
